# vim: ts=4 sw=4 noexpandtab
"""ClanMatch module.

This is a Clan Match ModManager module

===== Config =====
 # Switches the players from one team to the other if enabled
 mm_clanmatch.roundSwitch 1
 
===== History =====
 v1.1 - 25/11/2005:
 Enabled roundSwitch config option

 v1.0 - 30/10/2005:
 Initial version

Copyright (c)2005 Multiplay
Author: Steven 'Killing' Hartland
"""

import bf2
import host
import mm_utils

# Set the version of your module here
__version__ = 1.1

# Set the required module versions here
__required_modules__ = {
	'modmanager': 1.0
}

# Does this module support reload ( are all its reference closed on shutdown? )
__supports_reload__ = True

# Set the description of your module here
__description__ = "ClanMatch v%s" % __version__

# Add all your configuration options here
configDefaults = {
	'roundSwitch': 1,
}

class ClanMatch( object ):

	def __init__( self, modManager ):
		# ModManager reference
		self.mm = modManager

		# Internal shutdown state
		self.__state = 0

		# Add any static initialisation here.
		# Note: Handler registration should not be done here
		# but instead in the init() method

	def cmdExec( self, ctx, cmd ):
		"""Execute a MyModule sub command."""

		# Note: The Python doc above is used for help / description
		# messages in rcon if not overriden
		return mm_utils.exec_subcmd( self.mm, self.__cmds, ctx, cmd )

	def onGameStatusChanged( self, status ):
		"""Switch players to the other team if end of round"""
		if bf2.GameStatus.PreGame == status and bf2.GameStatus.EndGame == self.mm.lastGameStatus and self.__config['roundSwitch']:
			# End of round so swap players
			for player in bf2.playerManager.getPlayers():
				# avoid autobalance changing us back
				player.setSuicide( 1 )
				# Change their team
				if 1 == player.getTeam():
					player.setTeam( 2 )
				else:
					player.setTeam( 1 )

	def init( self ):
		"""Provides default initialisation."""

		# Load the configuration
		self.__config = self.mm.getModuleConfig( configDefaults )

		# Register your game handlers and provide any
		# other dynamic initialisation here
		host.registerGameStatusHandler( self.onGameStatusChanged )

		# Update to the running state
		self.__state = 1

	def shutdown( self ):
		"""Shutdown and stop processing."""

		# Unregister game handlers and do any other
		# other actions to ensure your module no longer affects
		# the game in anyway
		host.unregisterGameStatusHandler( self.onGameStatusChanged )

		# Flag as shutdown as there is currently way to:
		# host.unregisterHandler
		self.__state = 2

	def update( self ):
		"""Process and update.
		Note: This is called VERY often processing in here should
		be kept to an absolute minimum.
		"""
		pass

def mm_load( modManager ):
	"""Creates and returns your object."""
	return ClanMatch( modManager )
